==> openapi_jira_client-0.0.1-py3-none-any.whl: openapi_jira_client/api/issue_type_screen_schemes/create_issue_type_screen_scheme.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.issue_type_screen_scheme_details import IssueTypeScreenSchemeDetails
from ...models.issue_type_screen_scheme_id import IssueTypeScreenSchemeId
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    json_body: IssueTypeScreenSchemeDetails,
) -> Dict[str, Any]:
    url = "{}/rest/api/3/issuetypescreenscheme".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[IssueTypeScreenSchemeId, None]]:
    if response.status_code == 201:
        response_201 = IssueTypeScreenSchemeId.from_dict(response.json())

        return response_201
    if response.status_code == 400:
        response_400 = None

        return response_400
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 409:
        response_409 = None

        return response_409
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[IssueTypeScreenSchemeId, None]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: IssueTypeScreenSchemeDetails,
) -> Response[Union[IssueTypeScreenSchemeId, None]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    json_body: IssueTypeScreenSchemeDetails,
) -> Optional[Union[IssueTypeScreenSchemeId, None]]:
    """Creates an issue type screen scheme.

    **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg)."""

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: IssueTypeScreenSchemeDetails,
) -> Response[Union[IssueTypeScreenSchemeId, None]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: IssueTypeScreenSchemeDetails,
) -> Optional[Union[IssueTypeScreenSchemeId, None]]:
    """Creates an issue type screen scheme.

    **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg)."""

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed

==> openapi_jira_client-3.0.0-py3-none-any.whl: openapi_jira_client/api/issue_type_screen_schemes/create_issue_type_screen_scheme.py <==
from typing import Any, Dict, List, Optional, Union, cast

import httpx
from attr import asdict

from ...client import AuthenticatedClient, Client
from ...models.issue_type_screen_scheme_details import IssueTypeScreenSchemeDetails
from ...models.issue_type_screen_scheme_id import IssueTypeScreenSchemeId
from ...types import UNSET, Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    json_body: IssueTypeScreenSchemeDetails,
) -> Dict[str, Any]:
    url = "{}/rest/api/3/issuetypescreenscheme".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[IssueTypeScreenSchemeId, None, None, None, None, None]]:
    if response.status_code == 201:
        response_201 = IssueTypeScreenSchemeId.from_dict(response.json())

        return response_201
    if response.status_code == 400:
        response_400 = None

        return response_400
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 409:
        response_409 = None

        return response_409
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[IssueTypeScreenSchemeId, None, None, None, None, None]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: IssueTypeScreenSchemeDetails,
) -> Response[Union[IssueTypeScreenSchemeId, None, None, None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    json_body: IssueTypeScreenSchemeDetails,
) -> Optional[Union[IssueTypeScreenSchemeId, None, None, None, None, None]]:
    """Creates an issue type screen scheme.

    **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg)."""

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: IssueTypeScreenSchemeDetails,
) -> Response[Union[IssueTypeScreenSchemeId, None, None, None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: IssueTypeScreenSchemeDetails,
) -> Optional[Union[IssueTypeScreenSchemeId, None, None, None, None, None]]:
    """Creates an issue type screen scheme.

    **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg)."""

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed
